/*
 *   Jackbeat - JACK sequencer
 *    
 *   Copyright (c) 2004-2008 Olivier Guilyardi <olivier {at} samalyse {dot} com>
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   SVN:$Id: error.h 121 2008-01-10 00:17:40Z olivier $
 */

#ifndef JACKBEAT_ERR_H
#define JACKBEAT_ERR_H


#define ERR_JAB_XML                 1
#define ERR_SEQUENCE_INTERNAL       2
#define ERR_SEQUENCE_MSQ            3 // obsolete
#define ERR_SEQUENCE_JACK_CONNECT   4
#define ERR_SEQUENCE_JACK_ACTIVATE  5
#define ERR_SEQUENCE_JACK_REGPORT   6

char * error_to_string (int code);

#endif
